Introduction
============

ooetl python module is a framework we use at Openpolis, in
order to write `ETL`_ processes.

.. moduleauthor:: Guglielmo Celata <guglielmo@openpolis.it>

Its main scope is to make it easy for the developers to write parsing,
transformation and loading code, re-using logic wherever possible
and writing custom code only when needed.

.. _ETL: https://en.wikipedia.org/wiki/Extract,_transform,_load
